==> qt6-quick3d-6.2.3-3-aarch64.pkg.tar.xz: usr/lib/cmake/Qt6Quick3DTools/Qt6Quick3DToolsTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::balsam" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::balsam APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::balsam PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/balsam"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::balsam )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::balsam "${_IMPORT_PREFIX}/lib/qt6/bin/balsam" )

# Import target "Qt6::balsamui" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::balsamui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::balsamui PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/balsamui"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::balsamui )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::balsamui "${_IMPORT_PREFIX}/lib/qt6/bin/balsamui" )

# Import target "Qt6::meshdebug" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::meshdebug APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::meshdebug PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/meshdebug"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::meshdebug )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::meshdebug "${_IMPORT_PREFIX}/lib/qt6/bin/meshdebug" )

# Import target "Qt6::shadergen" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::shadergen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::shadergen PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/shadergen"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::shadergen )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::shadergen "${_IMPORT_PREFIX}/lib/qt6/bin/shadergen" )

# Import target "Qt6::instancer" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::instancer APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::instancer PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/instancer"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::instancer )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::instancer "${_IMPORT_PREFIX}/lib/qt6/bin/instancer" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> qt6-quick3d-6.3.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/Qt6Quick3DTools/Qt6Quick3DToolsTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::balsam" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::balsam APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::balsam PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/balsam"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::balsam )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::balsam "${_IMPORT_PREFIX}/lib/qt6/bin/balsam" )

# Import target "Qt6::balsamui" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::balsamui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::balsamui PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/balsamui"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::balsamui )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::balsamui "${_IMPORT_PREFIX}/lib/qt6/bin/balsamui" )

# Import target "Qt6::meshdebug" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::meshdebug APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::meshdebug PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/meshdebug"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::meshdebug )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::meshdebug "${_IMPORT_PREFIX}/lib/qt6/bin/meshdebug" )

# Import target "Qt6::shadergen" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::shadergen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::shadergen PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/shadergen"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::shadergen )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::shadergen "${_IMPORT_PREFIX}/lib/qt6/bin/shadergen" )

# Import target "Qt6::instancer" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::instancer APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::instancer PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/instancer"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::instancer )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::instancer "${_IMPORT_PREFIX}/lib/qt6/bin/instancer" )

# Import target "Qt6::shapegen" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::shapegen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::shapegen PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/shapegen"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::shapegen )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::shapegen "${_IMPORT_PREFIX}/lib/qt6/bin/shapegen" )

# Import target "Qt6::materialeditor" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::materialeditor APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::materialeditor PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/materialeditor"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::materialeditor )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::materialeditor "${_IMPORT_PREFIX}/lib/qt6/bin/materialeditor" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
